Module blaxel.core.sandbox.client.models.process_logs
=====================================================

Classes
-------

`ProcessLogs(logs: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>, stderr: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>, stdout: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>)`
:   Attributes:
        logs (Union[Unset, str]):  Example: logs output.
        stderr (Union[Unset, str]):  Example: stderr output.
        stdout (Union[Unset, str]):  Example: stdout output.
    
    Method generated by attrs for class ProcessLogs.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `logs: blaxel.core.sandbox.client.types.Unset | str`
    :

    `stderr: blaxel.core.sandbox.client.types.Unset | str`
    :

    `stdout: blaxel.core.sandbox.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :